@@ -41,6 +41,10 @@ def period_mapping(period):
     elif period == 'Last 30 Days':
         _end_date = now.replace(hour=0, minute=0, second=0, microsecond=0)
         start_date = (_end_date - timedelta(days=30)).strftime(DATETIME_FORMAT)
+    else:
+        dates = period.split(' - ')
+        start_date = datetime.strptime(dates[0], '%m/%d/%y').strftime(DATETIME_FORMAT)
+        _end_date = datetime.strptime(dates[1], '%m/%d/%y')
 
     end_date = _end_date.strftime(DATETIME_FORMAT)
 
@@ -88,8 +92,8 @@ class Analysis(Base, DictMixin):
     tenant_id = Column(String(32))
 
     app = relationship("InstalledApp", back_populates="analyses", lazy=False)
-    runs = relationship("AnalysisRun", back_populates="analysis")
-    sends = relationship("AnalysisSend", back_populates="analysis")
+    runs = relationship("AnalysisRun", back_populates="analysis", passive_deletes=True)
+    sends = relationship("AnalysisSend", back_populates="analysis", passive_deletes=True)
 
     class Meta:
         fields = ('id', 'name', 'params', 'created', 'tenant_id')
@@ -137,7 +141,7 @@ class AnalysisRun(Base, DictMixin):
     __tablename__ = 'core_analysisrun'
 
     id = Column(String(32), primary_key=True, default=generate_uuid)
-    analysis_id = Column(String(32), ForeignKey('core_analysis.id'))
+    analysis_id = Column(String(32), ForeignKey('core_analysis.id', ondelete='CASCADE'))
     params = Column(JSON)
     date_launched = Column(DateTime, default=datetime.utcnow)
     date_completed = Column(DateTime)
@@ -147,7 +151,7 @@ class AnalysisRun(Base, DictMixin):
     triggered_by_id = Column(String(32), nullable=False)  # user id
 
     analysis = relationship("Analysis", back_populates="runs", lazy=False)
-    exports = relationship("AnalysisExport", back_populates="run")
+    exports = relationship("AnalysisExport", back_populates="run", passive_deletes=True)
 
     class Meta:
         fields = ('id', 'analysis_id', 'params', 'date_launched', 'date_completed', 'is_saved')
@@ -173,13 +177,14 @@ class AnalysisSend(Base, DictMixin):
     __tablename__ = 'core_analysissend'
 
     id = Column(String(32), primary_key=True, default=generate_uuid)
-    analysis_id = Column(String(32), ForeignKey('core_analysis.id'))
+    analysis_id = Column(String(32), ForeignKey('core_analysis.id', ondelete='CASCADE'))
     subject = Column(String(200), nullable=False)
     format = Column(String(20), default='pdf')
     schedule = Column(String(50))
     recepients = Column(TEXT)
     message = Column(TEXT)
     attachment = Column(String(500))
+    jwt_token = Column(TEXT)
     is_active = Column(Boolean, default=True)
     is_ran = Column(Boolean, default=False)
     last_ran = Column(DateTime, default=datetime.utcnow)
@@ -197,7 +202,7 @@ class AnalysisExport(Base, DictMixin):
     __tablename__ = 'core_analysisexport'
 
     id = Column(String(32), primary_key=True, default=generate_uuid)
-    run_id = Column(String(32), ForeignKey('core_analysisrun.id'))
+    run_id = Column(String(32), ForeignKey('core_analysisrun.id', ondelete='CASCADE'))
     url = Column(String(300))
     created = Column(DateTime, default=datetime.utcnow)
     modified = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)
