@@ -1,9 +1,11 @@
 import os
 import time
-
+import logging
 from io import BytesIO
 from datetime import datetime
 
+import json
+
 from urllib.request import urlopen
 from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
@@ -28,6 +30,17 @@ AWS_SECRET_ACCESS_KEY = os.getenv('AWS_SECRET_ACCESS_KEY')
 REGION_NAME = os.getenv('REGION_NAME')
 S3_BUCKET_NAME = os.getenv('S3_BUCKET_NAME')
 API_RETRY = int(os.getenv('API_RETRY', 3))
+API_KEY = os.getenv('API_KEY')
+API_SECRET = os.getenv('API_SECRET')
+
+def get_token():
+    headers = {"Content-Type" : "application/x-www-form-urlencoded" , "Accept" : "application/json"};
+    post_data = {"grant_type": "client_credentials", "client_id" : API_KEY, "client_secret" : API_SECRET};
+    token_url = BASE_API_URL + "/auth/oauth/token";
+    response = requests.post(token_url,data=post_data,headers=headers,verify=False);
+    json = response.json();
+    auth = str(json["access_token"])
+    return auth
 
 
 def get_jwt_token():
@@ -41,7 +54,9 @@ def get_jwt_token():
 
 def get_headers():
     headers = {
-        'Authorization': f'Bearer {get_jwt_token()}'
+        'Content-Type': 'application/json',
+        'Accept': 'application/json',
+        'Authorization': f'Bearer {get_token()}'
     }
 
     return headers
@@ -75,6 +90,7 @@ def call_requests(method, url, params=None, data=None, json=None, verify=True):
             resp = requests.request(method, url, params=params, data=data, json=json, headers=headers, verify=verify)
         except requests.exceptions.ConnectionError:
             time.sleep(retry * 2)
+            retry+=1
             continue
 
         return resp
@@ -87,7 +103,6 @@ def call_get_requests(url, params=None, verify=True):
 def call_post_requests(url, params=None, data=None, verify=True):
     return call_requests('POST', url, params, data, verify=verify)
 
-
 def is_authenticated():
     REQUIRE_AUTH_REDIRECT = os.getenv('REQUIRE_AUTH_REDIRECT') == 'true'
     if not REQUIRE_AUTH_REDIRECT:
@@ -114,15 +129,38 @@ def get_epoc_from_datetime_string(str_datetime):
     timestamp = datetime.strptime(str_datetime, DATETIME_FORMAT).timestamp()
     return timestamp
 
+def get_run_result(run_id, field=None, default_value=None):
+    with Session() as session:
+        run = session.query(AnalysisRun).filter_by(id=run_id).first()
 
-def get_run_result(run_id):
+    result = run.get_result() if run else {}
+    if field:
+        result = result.get(field, default_value)
+
+    return result
+
+def get_result_by_run(run_id, field=None, default_value=None):
+    logging.error(f'{" "} <-----   Entered Into get result by run   ----->')
+    try:
+        s3 = get_s3_client()
+        run_id= f'analytics-apps/json/{run_id}'
+        res_object = s3.get_object(Bucket=S3_BUCKET_NAME,Key=run_id)
+        serializedObject = res_object['Body'].read()
+        result = json.loads(serializedObject)
+        if field:
+            result = result.get(field, default_value)
+        return result
+    except Exception:
+        logging.error('<An error occurred (NoSuchKey) when calling the GetObject operation: The specified key does not exist>')
+        pass
+
+
+def get_run_params(run_id, field=None, default_value=None):
     with Session() as session:
         run = session.query(AnalysisRun).filter_by(id=run_id).first()
 
     if run:
-        return run.get_result()
-    else:
-        return {}
+        return run.params
 
 
 def get_ses_client():
@@ -132,6 +170,13 @@ def get_ses_client():
                         aws_secret_access_key=AWS_SECRET_ACCESS_KEY)
 
 
+def get_s3_client():
+    return boto3.client('s3',
+                        region_name=REGION_NAME,
+                        aws_access_key_id=AWS_ACCESS_KEY_ID,
+                        aws_secret_access_key=AWS_SECRET_ACCESS_KEY)
+    
+
 def send_email(subject, from_email, to_emails, body, attachment=None):
     message = MIMEMultipart()
     message['Subject'] = subject
@@ -172,30 +217,33 @@ def upload_to_s3(content, location):
 
     try:
         s3.Bucket(S3_BUCKET_NAME).put_object(Body=content,
-                                             Key=location,
-                                             ACL='public-read')
+                                             Key=location)
         return object_url
     except Exception:
         pass
+    
 
-
-def generate_pdf(analysis_run):
+def generate_pdf(analysis_run, app_name):
+    logging.error(f'{"Pdf"} <-----   Entered Into Pdf Generation Process   ----->')
     url = os.getenv("PDF_SERVICE")
-
+    route = os.getenv("PLATFORM_ROUTE")
+    # analysis_run = json.dumps(analysis_run)
     data = {
-        'domain': analysis_run.analysis.app.app_domain,
-        'report': analysis_run.analysis.app.slug,
-        'run': analysis_run.id,
+        'domain': 'https://asura.opsramp.net',
+        'report': route,
+        'run': analysis_run,
         'route': '/full-view',
-        'jwt_token': get_jwt_token(),
+        'token': get_token(),
+        'app_name': app_name,
         'size': 'A4'
     }
 
     res = requests.post(url, data=data).json()
-
+    logging.error(f'{res} <-----     Pdf Response     ----->')
     return res
 
 
+
 def generate_excel(analysis_run, file_name=None):
     try:
         excel_renderer = ExcelRenderer(analysis_run)
